==> haskell-gio-0.13.11.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gio
version:                0.13.11.0
visibility:             public
id:                     gio-0.13.11.0-GeVwgLa0P2s8uwViKfCFex
key:                    gio-0.13.11.0-GeVwgLa0P2s8uwViKfCFex
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Peter Gavin, Andy Stewart
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to GIO
description:
    GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
    The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
    so good that developers prefer it over raw POSIX calls.
    Among other things that means using GObject.
    It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.

category:               System
abi:                    82c6bebfb90b88acdf29c6b4b50655bb
exposed:                True
exposed-modules:
    System.GIO System.GIO.Async.AsyncResult
    System.GIO.Async.Cancellable System.GIO.Enums
    System.GIO.File.AppInfo System.GIO.File.ContentType
    System.GIO.File.File System.GIO.File.FileAttribute
    System.GIO.File.FileEnumerator System.GIO.File.FileInfo
    System.GIO.File.FileMonitor System.GIO.File.IOError
    System.GIO.File.MountOperation System.GIO.Icons.Emblem
    System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
    System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon System.GIO.Types
    System.GIO.Volumes.Drive System.GIO.Volumes.Mount
    System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor

hidden-modules:         System.GIO.Signals
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gio
hs-libraries:           HSgio-0.13.11.0-GeVwgLa0P2s8uwViKfCFex
extra-libraries:        gio-2.0 gobject-2.0 glib-2.0
extra-libraries-static:
    gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount
    blkid sysprof-capture-4

include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    glib-0.13.11.0-4oyX2pERoLrHuBvxWitH1B mtl-2.2.2

haddock-interfaces:     /usr/share/doc/haskell-gio/html/gio.haddock
haddock-html:           /usr/share/doc/haskell-gio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gio-0.13.11.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gio
version:                0.13.11.0
visibility:             public
id:                     gio-0.13.11.0-2PDkzopqFmLBN7KgDaG69g
key:                    gio-0.13.11.0-2PDkzopqFmLBN7KgDaG69g
license:                LGPL-2.1-only
copyright:              (c) 2001-2010 The Gtk2Hs Team
maintainer:             gtk2hs-users@lists.sourceforge.net
author:                 Peter Gavin, Andy Stewart
stability:              stable
homepage:               http://projects.haskell.org/gtk2hs/
synopsis:               Binding to GIO
description:
    GIO is striving to provide a modern, easy-to-use VFS API that sits at the right level in the library stack.
    The goal is to overcome the shortcomings of GnomeVFS and provide an API that is
    so good that developers prefer it over raw POSIX calls.
    Among other things that means using GObject.
    It also means not cloning the POSIX API, but providing higher-level, document-centric interfaces.

category:               System
abi:                    12e70e4823dc0ece2c1346f625b8f2ed
exposed:                True
exposed-modules:
    System.GIO System.GIO.Async.AsyncResult
    System.GIO.Async.Cancellable System.GIO.Enums
    System.GIO.File.AppInfo System.GIO.File.ContentType
    System.GIO.File.File System.GIO.File.FileAttribute
    System.GIO.File.FileEnumerator System.GIO.File.FileInfo
    System.GIO.File.FileMonitor System.GIO.File.IOError
    System.GIO.File.MountOperation System.GIO.Icons.Emblem
    System.GIO.Icons.EmblemedIcon System.GIO.Icons.FileIcon
    System.GIO.Icons.Icon System.GIO.Icons.ThemedIcon System.GIO.Types
    System.GIO.Volumes.Drive System.GIO.Volumes.Mount
    System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor

hidden-modules:         System.GIO.Signals
import-dirs:            /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
library-dirs:           /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/gio-0.13.11.0
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-gio
hs-libraries:           HSgio-0.13.11.0-2PDkzopqFmLBN7KgDaG69g
extra-libraries:        gio-2.0 gobject-2.0 glib-2.0
extra-libraries-static:
    gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0 m pcre2-8 z mount
    blkid sysprof-capture-4

include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    glib-0.13.11.0-JUoJBi0CvyKQckEGRYkRl mtl-2.2.2

haddock-interfaces:     /usr/share/doc/haskell-gio/html/gio.haddock
haddock-html:           /usr/share/doc/haskell-gio/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
